# remirepo/fedora spec file for php-horde-Horde-Xml-Wbxml
#
# Copyright (c) 2012-2019 Nick Bebout, Remi Collet
#
# License: MIT
# https://fedoraproject.org/wiki/Licensing:MIT#Modern_Style_with_sublicense
#
# Please, preserve the changelog entries
#
%{!?__pear:       %global __pear       %{_bindir}/pear}
%global pear_name    Horde_Xml_Wbxml
%global pear_channel pear.horde.org

Name:           php-horde-Horde-Xml-Wbxml
Version:        2.0.3
Release:        8%{?dist}
Summary:        Provides an API for encoding and decoding WBXML documents

License:        LGPLv2
URL:            http://%{pear_channel}
Source0:        http://%{pear_channel}/get/%{pear_name}-%{version}.tgz

Patch0:         %{pear_name}-php74.patch

BuildArch:      noarch
BuildRequires:  php-common >= 5.3.0
BuildRequires:  php-pear(PEAR) >= 1.7.0
BuildRequires:  php-channel(%{pear_channel})
# To run unit tests
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-pear(%{pear_channel}/Horde_Util) >= 2.0.0  with php-pear(%{pear_channel}/Horde_Util) < 3)
BuildRequires: (php-pear(%{pear_channel}/Horde_Test) >= 2.1.0  with php-pear(%{pear_channel}/Horde_Test) < 3)
%else
BuildRequires:  php-pear(%{pear_channel}/Horde_Test) >= 2.1.0
BUildRequires:  php-pear(%{pear_channel}/Horde_Util) >= 2.0.0
%endif
BuildRequires:  php-xml
%if 0%{?fedora} > 12
BuildRequires:  libwbxml
%endif

Requires(post): %{__pear}
Requires(postun): %{__pear}
Requires:       php-common >= 5.3.0
Requires:       php-pear(PEAR) >= 1.7.0
Requires:       php-pcre
Requires:       php-xml
Requires:       php-channel(%{pear_channel})
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-pear(%{pear_channel}/Horde_Util) >= 2.0.0  with php-pear(%{pear_channel}/Horde_Util) < 3)
%else
Requires:       php-pear(%{pear_channel}/Horde_Util) >= 2.0.0
Requires:       php-pear(%{pear_channel}/Horde_Util) <  3.0.0
%endif*

Provides:       php-pear(%{pear_channel}/%{pear_name}) = %{version}
Provides:       php-composer(horde/horde-xml-wbxml) = %{version}


%description
This package provides encoding and decoding of WBXML (Wireless Binary XML)
documents. WBXML is used in SyncML for transferring smaller amounts of data
with wireless devices.

%prep
%setup -q -c

cd %{pear_name}-%{version}
%patch0 -p1

sed -e '/.php/s/md5sum=.*name=/name=/' \
    ../package.xml >%{name}.xml
touch -r ../package.xml %{name}.xml


%build
cd %{pear_name}-%{version}
# Empty build section, most likely nothing required.


%install
cd %{pear_name}-%{version}
%{__pear} install --nodeps --packagingroot %{buildroot} %{name}.xml

# Clean up unnecessary files
rm -rf %{buildroot}%{pear_metadir}/.??*

# Install XML package description
mkdir -p %{buildroot}%{pear_xmldir}
install -pm 644 %{name}.xml %{buildroot}%{pear_xmldir}


%check
cd %{pear_name}-%{version}/test/$(echo %{pear_name} | sed -e s:_:/:g)


# ignore test when wbxml2xml fails
sed -e '/assertEquals/s/^/if ($xml_ref) /' \
    -i DecodeTest.php

ret=0
for cmd in php php71 php72 php73 php74; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit --verbose . || ret=1
  fi
done
exit $ret


%post
%{__pear} install --nodeps --soft --force --register-only \
    %{pear_xmldir}/%{name}.xml >/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    %{__pear} uninstall --nodeps --ignore-errors --register-only \
        %{pear_channel}/%{pear_name} >/dev/null || :
fi


%files
%doc %{pear_docdir}/%{pear_name}
%{pear_xmldir}/%{name}.xml
%dir %{pear_phpdir}/Horde/Xml
%{pear_phpdir}/Horde/Xml/Wbxml
%{pear_phpdir}/Horde/Xml/Wbxml.php
%doc %{pear_testdir}/%{pear_name}


%changelog
* Fri Nov 15 2019 Remi Collet <remi@fedoraproject.org> - 2.0.3-8
- add patch for PHP 7.4
  from https://github.com/horde/Xml_Wbxml/pull/1
- use range dependencies

* Tue Feb 02 2016 Remi Collet <remi@fedoraproject.org> - 2.0.3-1
- Update to 2.0.3
- PHP 7 compatible version
- run test suite with both PHP 5 and 7 when available

* Fri Jan 09 2015 Remi Collet <remi@fedoraproject.org> - 2.0.2-1
- Update to 2.0.2
- add provides php-composer(horde/horde-xml-wbxml)

* Sun Feb 10 2013 Remi Collet <remi@fedoraproject.org> - 2.0.1-3
- missing requires, from review #908357

* Wed Feb  6 2013 Remi Collet <remi@fedoraproject.org> - 2.0.1-2
- cleanups for review

* Mon Nov 19 2012 Remi Collet <remi@fedoraproject.org> - 2.0.1-1
- Update to 2.0.1

* Thu Nov  1 2012 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- Update to 2.0.0

* Sat Jan 28 2012 Nick Bebout <nb@fedoraproject.org> - 1.0.3-1
- Initial package
